@@ -27,6 +27,7 @@ import fnmatch
 import io
 import logging
 import os
+import pathlib
 import re
 import signal
 import string
@@ -39,7 +40,7 @@ import pyflakes.messages
 import pyflakes.reporter
 
 
-__version__ = "1.6.1"
+__version__ = "1.7.0"
 
 
 _LOGGER = logging.getLogger("autoflake")
@@ -940,6 +941,14 @@ def _fix_file(
                 f"{filename}: Unused imports/variables detected{os.linesep}",
             )
             return 1
+        if args["check_diff"]:
+            diff = get_diff_text(
+                io.StringIO(original_source).readlines(),
+                io.StringIO(filtered_source).readlines(),
+                filename,
+            )
+            standard_out.write("".join(diff))
+            return 1
         if write_to_stdout:
             standard_out.write(filtered_source)
         elif args["in_place"]:
@@ -960,8 +969,8 @@ def _fix_file(
     elif write_to_stdout:
         standard_out.write(filtered_source)
     else:
-        if args["check"] and not args["quiet"]:
-            standard_out.write(f"No issues detected!{os.linesep}")
+        if (args["check"] or args["check_diff"]) and not args["quiet"]:
+            standard_out.write(f"{filename}: No issues detected!{os.linesep}")
         else:
             _LOGGER.debug("Clean %s: nothing to fix", filename)
 
@@ -1128,36 +1137,24 @@ def process_pyproject_toml(toml_file_path):
         return tomllib.load(f).get("tool", {}).get("autoflake", None)
 
 
-def process_setup_cfg(cfg_file_path):
-    """Extract config mapping from setup.cfg file."""
+def process_config_file(config_file_path):
+    """Extract config mapping from config file."""
     import configparser
 
     reader = configparser.ConfigParser()
-    reader.read(cfg_file_path)
+    reader.read(config_file_path)
     if not reader.has_section("autoflake"):
         return None
 
     return reader["autoflake"]
 
 
-def merge_configuration_file(args):
-    """Merge configuration from a file into args."""
+def find_and_process_config(args):
     # Configuration file parsers {filename: parser function}.
     CONFIG_FILES = {
         "pyproject.toml": process_pyproject_toml,
-        "setup.cfg": process_setup_cfg,
+        "setup.cfg": process_config_file,
     }
-    BOOL_TYPES = {
-        "1": True,
-        "yes": True,
-        "true": True,
-        "on": True,
-        "0": False,
-        "no": False,
-        "false": False,
-        "off": False,
-    }
-
     # Traverse the file tree common to all files given as argument looking for
     # a configuration file
     config_path = os.path.commonpath([os.path.abspath(file) for file in args.files])
@@ -1176,6 +1173,35 @@ def merge_configuration_file(args):
         config_path, tail = os.path.split(config_path)
         if not tail:
             break
+    return config
+
+
+def merge_configuration_file(args):
+    """Merge configuration from a file into args."""
+    BOOL_TYPES = {
+        "1": True,
+        "yes": True,
+        "true": True,
+        "on": True,
+        "0": False,
+        "no": False,
+        "false": False,
+        "off": False,
+    }
+
+    if args.config_file:
+        config_file = pathlib.Path(args.config_file).resolve()
+        config = process_config_file(config_file)
+
+        if not config:
+            _LOGGER.error(
+                "can't parse config file '%s'",
+                config_file,
+            )
+            return False
+    else:
+        config = find_and_process_config(args)
+
     if config:
         # merge config
         for name, value in config.items():
@@ -1198,6 +1224,7 @@ def merge_configuration_file(args):
                 setattr(args, name, value)
             elif name in {
                 "check",
+                "check_diff",
                 "expand-star-imports",
                 "ignore-init-module-imports",
                 "ignore-pass-after-docstring",
@@ -1211,7 +1238,7 @@ def merge_configuration_file(args):
             }:
                 # boolean properties
                 if isinstance(value, str):
-                    value = BOOL_TYPES.get(value, value)
+                    value = BOOL_TYPES.get(value.lower(), value)
                 if not isinstance(value, bool):
                     _LOGGER.error(
                         "'%s' in the config file should be a boolean",
@@ -1235,12 +1262,19 @@ def _main(argv, standard_out, standard_error, standard_input=None) -> int:
     import argparse
 
     parser = argparse.ArgumentParser(description=__doc__, prog="autoflake")
-    parser.add_argument(
+    check_group = parser.add_mutually_exclusive_group()
+    check_group.add_argument(
         "-c",
         "--check",
         action="store_true",
         help="return error code if changes are needed",
     )
+    check_group.add_argument(
+        "-cd",
+        "--check-diff",
+        action="store_true",
+        help="return error code if changes are needed, also display file diffs",
+    )
     parser.add_argument(
         "-r",
         "--recursive",
@@ -1334,6 +1368,17 @@ def _main(argv, standard_out, standard_error, standard_input=None) -> int:
         default="stdin",
         help="the name used when processing input from stdin",
     )
+
+    parser.add_argument(
+        "--config",
+        dest="config_file",
+        default=None,
+        help=(
+            "Explicitly set the config file "
+            "instead of auto determining based on file location"
+        ),
+    )
+
     parser.add_argument("files", nargs="+", help="files to format")
 
     group = parser.add_mutually_exclusive_group()
