@@ -2081,7 +2081,7 @@ except ImportError:
                 standard_error=None,
             )
             self.assertEqual(
-                f"No issues detected!{os.linesep}",
+                f"{filename}: No issues detected!{os.linesep}",
                 output_file.getvalue(),
             )
 
@@ -2100,7 +2100,7 @@ print(x)
                 standard_error=None,
             )
             self.assertEqual(
-                f"No issues detected!{os.linesep}",
+                f"{filename}: No issues detected!{os.linesep}",
                 output_file.getvalue(),
             )
 
@@ -2172,6 +2172,101 @@ except ImportError:
                     set(output_file.getvalue().strip().split(os.linesep)),
                 )
 
+    def test_check_diff_with_empty_file(self):
+        line = ""
+
+        with temporary_file(line) as filename:
+            output_file = io.StringIO()
+            autoflake._main(
+                argv=["my_fake_program", "--check-diff", filename],
+                standard_out=output_file,
+                standard_error=None,
+            )
+            self.assertEqual(
+                f"{filename}: No issues detected!{os.linesep}",
+                output_file.getvalue(),
+            )
+
+    def test_check_diff_correct_file(self):
+        with temporary_file(
+            """\
+import foo
+x = foo.bar
+print(x)
+""",
+        ) as filename:
+            output_file = io.StringIO()
+            autoflake._main(
+                argv=["my_fake_program", "--check-diff", filename],
+                standard_out=output_file,
+                standard_error=None,
+            )
+            self.assertEqual(
+                f"{filename}: No issues detected!{os.linesep}",
+                output_file.getvalue(),
+            )
+
+    def test_check_diff_correct_file_with_quiet(self):
+        with temporary_file(
+            """\
+import foo
+x = foo.bar
+print(x)
+""",
+        ) as filename:
+            output_file = io.StringIO()
+            autoflake._main(
+                argv=[
+                    "my_fake_program",
+                    "--check-diff",
+                    "--quiet",
+                    filename,
+                ],
+                standard_out=output_file,
+                standard_error=None,
+            )
+            self.assertEqual("", output_file.getvalue())
+
+    def test_check_diff_useless_pass(self):
+        with temporary_file(
+            """\
+import foo
+x = foo
+import subprocess
+x()
+try:
+    pass
+    import os
+except ImportError:
+    pass
+    import os
+    import sys
+""",
+        ) as filename:
+            output_file = io.StringIO()
+            exit_status = autoflake._main(
+                argv=["my_fake_program", "--check-diff", filename],
+                standard_out=output_file,
+                standard_error=None,
+            )
+            self.assertEqual(exit_status, 1)
+            self.assertEqual(
+                """\
+ import foo
+ x = foo
+-import subprocess
+ x()
+ try:
+     pass
+-    import os
+ except ImportError:
+     pass
+-    import os
+-    import sys
+""",
+                "\n".join(output_file.getvalue().split("\n")[3:]),
+            )
+
     def test_in_place_with_empty_file(self):
         line = ""
 
@@ -3043,7 +3138,10 @@ class ConfigFileTest(unittest.TestCase):
 
     def test_no_config_file(self):
         self.create_file("test_me.py")
-        original_args = {"files": [self.effective_path("test_me.py")]}
+        original_args = {
+            "files": [self.effective_path("test_me.py")],
+            "config_file": None,
+        }
         args = Namespace(**original_args)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(args, original_args)
@@ -3052,9 +3150,9 @@ class ConfigFileTest(unittest.TestCase):
         self.create_file("test_me.py")
         self.create_file("pyproject.toml", '[tool.other]\nprop="value"\n')
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
-        self.assert_namespace(args, {"files": files})
+        self.assert_namespace(args, {"files": files, "config_file": None})
 
     def test_non_nested_pyproject_toml_non_empty(self):
         self.create_file("test_me.py")
@@ -3063,11 +3161,11 @@ class ConfigFileTest(unittest.TestCase):
             "[tool.autoflake]\nexpand-star-imports=true\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "expand_star_imports": True},
+            {"files": files, "expand_star_imports": True, "config_file": None},
         )
 
     def test_non_nested_setup_cfg_non_empty(self):
@@ -3077,11 +3175,11 @@ class ConfigFileTest(unittest.TestCase):
             "[other]\nexpand-star-imports = yes\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files},
+            {"files": files, "config_file": None},
         )
 
     def test_non_nested_setup_cfg_empty(self):
@@ -3091,11 +3189,11 @@ class ConfigFileTest(unittest.TestCase):
             "[autoflake]\nexpand-star-imports = yes\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "expand_star_imports": True},
+            {"files": files, "expand_star_imports": True, "config_file": None},
         )
 
     def test_nested_file(self):
@@ -3105,11 +3203,11 @@ class ConfigFileTest(unittest.TestCase):
             "[tool.autoflake]\nexpand-star-imports=true\n",
         )
         files = [self.effective_path("nested/file/test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "expand_star_imports": True},
+            {"files": files, "expand_star_imports": True, "config_file": None},
         )
 
     def test_common_path_nested_file_do_not_load(self):
@@ -3123,11 +3221,11 @@ class ConfigFileTest(unittest.TestCase):
             self.effective_path("nested/file/test_me.py"),
             self.effective_path("nested/other/test_me.py"),
         ]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files},
+            {"files": files, "config_file": None},
         )
 
     def test_common_path_nested_file_do_load(self):
@@ -3141,11 +3239,11 @@ class ConfigFileTest(unittest.TestCase):
             self.effective_path("nested/file/test_me.py"),
             self.effective_path("nested/other/test_me.py"),
         ]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "expand_star_imports": True},
+            {"files": files, "expand_star_imports": True, "config_file": None},
         )
 
     def test_common_path_instead_of_common_prefix(self):
@@ -3160,11 +3258,11 @@ class ConfigFileTest(unittest.TestCase):
             self.effective_path("nested/file-foo/test_me.py"),
             self.effective_path("nested/file-bar/test_me.py"),
         ]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files},
+            {"files": files, "config_file": None},
         )
 
     def test_continue_search_if_no_config_found(self):
@@ -3178,11 +3276,11 @@ class ConfigFileTest(unittest.TestCase):
             "[tool.autoflake]\nexpand-star-imports = true\n",
         )
         files = [self.effective_path("nested/test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "expand_star_imports": True},
+            {"files": files, "expand_star_imports": True, "config_file": None},
         )
 
     def test_stop_search_if_config_found(self):
@@ -3196,13 +3294,32 @@ class ConfigFileTest(unittest.TestCase):
             "[tool.autoflake]\nexpand-star-imports = true\n",
         )
         files = [self.effective_path("nested/test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files},
+            {"files": files, "config_file": None},
         )
 
+    def test_config_option(self):
+        with temporary_file(
+            suffix=".ini",
+            contents=("[autoflake]\n" "check = True\n"),
+        ) as temp_config:
+            self.create_file("test_me.py")
+            files = [self.effective_path("test_me.py")]
+
+            args = Namespace(config_file=temp_config, files=files)
+            assert autoflake.merge_configuration_file(args)
+            self.assert_namespace(
+                args,
+                {
+                    "config_file": temp_config,
+                    "check": True,
+                    "files": files,
+                },
+            )
+
     def test_dont_load_false(self):
         self.create_file("test_me.py")
         self.create_file(
@@ -3210,11 +3327,11 @@ class ConfigFileTest(unittest.TestCase):
             "[autoflake]\nexpand-star-imports = no\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files},
+            {"files": files, "config_file": None},
         )
 
     def test_list_value_pyproject_toml(self):
@@ -3224,11 +3341,11 @@ class ConfigFileTest(unittest.TestCase):
             '[tool.autoflake]\nimports=["my_lib", "other_lib"]\n',
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "imports": "my_lib,other_lib"},
+            {"files": files, "imports": "my_lib,other_lib", "config_file": None},
         )
 
     def test_list_value_comma_sep_string_pyproject_toml(self):
@@ -3238,11 +3355,11 @@ class ConfigFileTest(unittest.TestCase):
             '[tool.autoflake]\nimports="my_lib,other_lib"\n',
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "imports": "my_lib,other_lib"},
+            {"files": files, "imports": "my_lib,other_lib", "config_file": None},
         )
 
     def test_list_value_setup_cfg(self):
@@ -3252,11 +3369,11 @@ class ConfigFileTest(unittest.TestCase):
             "[autoflake]\nimports=my_lib,other_lib\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "imports": "my_lib,other_lib"},
+            {"files": files, "imports": "my_lib,other_lib", "config_file": None},
         )
 
     def test_unknown_property(self):
@@ -3266,7 +3383,7 @@ class ConfigFileTest(unittest.TestCase):
             "[tool.autoflake]\nunknown_prop=true\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert not autoflake.merge_configuration_file(args)
 
     def test_non_bool_value_for_bool_property(self):
@@ -3276,7 +3393,7 @@ class ConfigFileTest(unittest.TestCase):
             '[tool.autoflake]\nexpand-star-imports="invalid"\n',
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert not autoflake.merge_configuration_file(args)
 
     def test_non_bool_value_for_bool_property_in_setup_cfg(self):
@@ -3286,7 +3403,7 @@ class ConfigFileTest(unittest.TestCase):
             "[autoflake]\nexpand-star-imports=ok\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert not autoflake.merge_configuration_file(args)
 
     def test_non_list_value_for_list_property(self):
@@ -3296,7 +3413,7 @@ class ConfigFileTest(unittest.TestCase):
             "[tool.autoflake]\nexclude=true\n",
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files)
+        args = Namespace(files=files, config_file=None)
         assert not autoflake.merge_configuration_file(args)
 
     def test_merge_with_cli_set_list_property(self):
@@ -3306,11 +3423,11 @@ class ConfigFileTest(unittest.TestCase):
             '[tool.autoflake]\nimports=["my_lib"]\n',
         )
         files = [self.effective_path("test_me.py")]
-        args = Namespace(files=files, imports="other_lib")
+        args = Namespace(files=files, imports="other_lib", config_file=None)
         assert autoflake.merge_configuration_file(args)
         self.assert_namespace(
             args,
-            {"files": files, "imports": "my_lib,other_lib"},
+            {"files": files, "imports": "my_lib,other_lib", "config_file": None},
         )
 
 
